Learn R Programming

GCAI.bias (version 1.0)

index.mat.generation: Index Matrix Generation

Description

To generate S3 class of index

Usage

index.mat.generation(word.vec, pos.vec)

Arguments

word.vec
a vector of nucleotides, the default is c("A","T","C","G").
pos.vec
a vector of positions of local sequence, the default is -40 ~ 40.

Value

index.mat.generation return a list containing components:
mat
a matrix with nucleotides as row names and positions as column names will be returned, a $4\times81$ matrix will be returned with default arguments.

References

Cai G, RNA-SEQUENCING APPLICATIONS: GENE EXPRESSION QUANTIFICATION AND METHYLATOR PHENOTYPE IDENTIFICATION, Ph.D. Thesis, 2013

Examples

Run this code
word<-81
word.vec<-c("A","T","C","G")
pos.vec<-c((-(word-1)/2):((word-1)/2))

obj.index<-index.mat.generation(word.vec,pos.vec)

Run the code above in your browser using DataLab