Learn R Programming

GCAI.bias (version 1.0)

lm.estimate: Linear Model Fitting

Description

To estimating the coefficients by fitting the linear model

Usage

lm.estimate(obj.train, fit.cut.train = 5)

Arguments

obj.train
an object of training data generated from index.preprocess and counts.preprocess
fit.cut.train
the minimum counts of the data points used for model fitting, the default for spike-in training dataset is 5.

Value

a 1-column matrix of coefficients will be returned.

Details

It models the influence on the local sequence from the dissimilarity of spike-in transcripts measurement. The region of positions around hexamer primers can be defined by the variable "word".

References

Cai G, RNA-SEQUENCING APPLICATIONS: GENE EXPRESSION QUANTIFICATION AND METHYLATOR PHENOTYPE IDENTIFICATION, Ph.D. Thesis, 2013

See Also

index.preprocess,counts.preprocess

Examples

Run this code
word<-81

data(train.dat.seq)
data(train.dat.counts)

train.index<-index.preprocess(train.dat.seq,word)
obj.train<-counts.preprocess(train.dat.counts)
obj.train[["index"]]<-train.index

coe.lm<-lm.estimate(obj.train,fit.cut.train=5)

Run the code above in your browser using DataLab